@@ -810,7 +810,10 @@ class Update(MethodsInterface):
         SystemIni(self.clVars).setVar('system', {'last_check': str(int(time.time()))})
 
     def get_default_emerge_opts(self, depclean=False):
-        if depclean and self.clVars.GetBool('cl_update_with_bdeps_set'):
+        bdeps_val = self.clVars.Get('cl_update_with_bdeps_set')
+        if bdeps_val == "auto":
+            bdeps = " --with-bdeps-auto=y"
+        elif bdeps_val == "on":
             bdeps = " --with-bdeps=y"
         else:
             bdeps = " --with-bdeps=n"
