@@ -1436,7 +1436,7 @@ class VariableClUpdateKernelPkg(ReadonlyVariable):
         if src_path:
             qfile = process('/usr/bin/qfile', '-vqC', src_path)
             if qfile.success():
-                return qfile.read()
+                return qfile.read().strip()
         return ""
 
 
